/*******************************************************************************
* File Name: Control_RW_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Control_RW.h"

/* Check for removal by optimization */
#if !defined(Control_RW_Sync_ctrl_reg__REMOVED)

static Control_RW_BACKUP_STRUCT  Control_RW_backup = {0u};

    
/*******************************************************************************
* Function Name: Control_RW_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_RW_SaveConfig(void) 
{
    Control_RW_backup.controlState = Control_RW_Control;
}


/*******************************************************************************
* Function Name: Control_RW_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Control_RW_RestoreConfig(void) 
{
     Control_RW_Control = Control_RW_backup.controlState;
}


/*******************************************************************************
* Function Name: Control_RW_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_RW_Sleep(void) 
{
    Control_RW_SaveConfig();
}


/*******************************************************************************
* Function Name: Control_RW_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_RW_Wakeup(void)  
{
    Control_RW_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
